package de.unisaar.jfap.ex3;

/**
 * Provide a method that checks if a string is a palindrom.
 *
 * @author Joerg Steffen, DFKI
 */
public final class PalindromeChecker {

  private PalindromeChecker() {
    // private constructor to enforce noninstantiability
  }

  /**
   * Check if the given string is a palindrome.
   *
   * @param input the string to check
   * @return {@code true} if the given string is a palindrome, {@code false} otherwise
   */
  public static boolean isPalindrome(String input) {

    // create normalized input that contains only letters
    StringBuilder normalizedInput = new StringBuilder();
    for (char currentChar : input.toCharArray()) {
      // only append character if it's a letter
      if (Character.isLetter(currentChar)) {
        normalizedInput.append(currentChar);
      }
    }

    // compare normalized string with its reverse, ignoring case
    String normalizedString = normalizedInput.toString();
    String reverseString = normalizedInput.reverse().toString();
    return normalizedString.equalsIgnoreCase(reverseString);
  }
}
